## pyBOAT - A Biological Oscillations Analysis Toolkit ##


Tools for time-frequency analysis with Morlet Wavelets
Inspired by 'A Practical Guide to Wavelet Analysis' (Torrence
and Compo 1998), 'Identification of Chirps with Continuous Wavelet Transform'
(Carmona, Hwang and Torresani 1995)
and [The Scientist and Engineer's Guide to Digital Signal Processing](http://www.dspguide.com/).

Version 0.7 April 2020, Frieda Sorgenfrei and Gregor Mönke. 

Questions etc. please to gregor.moenke@embl.de.

**Contributers are welcome!**

### Features ###

* Optimal sinc filter
* Fourier analysis
* Wavelet analysis 
* Ridge detection
* Phase extraction
* Amplitude estimation
* Synthetic signal generator
